==> lokinet-docs-v0.9.9.tar.xz: lokinet-docs-v0.9.9/markdown/Namespaces/namespacellarp_1_1thread.md <==
---
title: llarp::thread

---

# llarp::thread



## Classes

|                | Name           |
| -------------- | -------------- |
| class | **[llarp::thread::QueuePushGuard](Classes/classllarp_1_1thread_1_1QueuePushGuard.md)**  |
| class | **[llarp::thread::QueuePopGuard](Classes/classllarp_1_1thread_1_1QueuePopGuard.md)**  |
| class | **[llarp::thread::Queue](Classes/classllarp_1_1thread_1_1Queue.md)**  |
| class | **[llarp::thread::QueueManager](Classes/classllarp_1_1thread_1_1QueueManager.md)**  |

## Types

|                | Name           |
| -------------- | -------------- |
| enum class uint32_t | **[ElementState](Namespaces/namespacellarp_1_1thread.md#enum-elementstate)** { Empty = 0, Writing = 1, Full = 2, Reading = 3} |
| enum class| **[QueueReturn](Namespaces/namespacellarp_1_1thread.md#enum-queuereturn)** { Success, QueueDisabled, QueueEmpty, QueueFull} |

## Functions

|                | Name           |
| -------------- | -------------- |
| std::ostream & | **[operator<<](Namespaces/namespacellarp_1_1thread.md#function-operator<<)**(std::ostream & os, QueueReturn val) |

## Types Documentation

### enum ElementState

| Enumerator | Value | Description |
| ---------- | ----- | ----------- |
| Empty | 0|   |
| Writing | 1|   |
| Full | 2|   |
| Reading | 3|   |




### enum QueueReturn

| Enumerator | Value | Description |
| ---------- | ----- | ----------- |
| Success | |   |
| QueueDisabled | |   |
| QueueEmpty | |   |
| QueueFull | |   |





## Functions Documentation

### function operator<<

```cpp
inline std::ostream & operator<<(
    std::ostream & os,
    QueueReturn val
)
```






-------------------------------

Updated on 2022-05-31 at 02:25:20 +0000

==> lokinet-docs-v0.9.11.tar.xz: lokinet-docs-v0.9.11/markdown/Namespaces/namespacellarp_1_1thread.md <==
---
title: llarp::thread

---

# llarp::thread



## Classes

|                | Name           |
| -------------- | -------------- |
| class | **[llarp::thread::QueuePushGuard](Classes/classllarp_1_1thread_1_1QueuePushGuard.md)**  |
| class | **[llarp::thread::QueuePopGuard](Classes/classllarp_1_1thread_1_1QueuePopGuard.md)**  |
| class | **[llarp::thread::Queue](Classes/classllarp_1_1thread_1_1Queue.md)**  |
| class | **[llarp::thread::QueueManager](Classes/classllarp_1_1thread_1_1QueueManager.md)**  |

## Types

|                | Name           |
| -------------- | -------------- |
| enum class uint32_t | **[ElementState](Namespaces/namespacellarp_1_1thread.md#enum-elementstate)** { Empty = 0, Writing = 1, Full = 2, Reading = 3} |
| enum class| **[QueueReturn](Namespaces/namespacellarp_1_1thread.md#enum-queuereturn)** { Success, QueueDisabled, QueueEmpty, QueueFull} |

## Functions

|                | Name           |
| -------------- | -------------- |
| constexpr std::string_view | **[ToString](Namespaces/namespacellarp_1_1thread.md#function-tostring)**(QueueReturn val) |

## Types Documentation

### enum ElementState

| Enumerator | Value | Description |
| ---------- | ----- | ----------- |
| Empty | 0|   |
| Writing | 1|   |
| Full | 2|   |
| Reading | 3|   |




### enum QueueReturn

| Enumerator | Value | Description |
| ---------- | ----- | ----------- |
| Success | |   |
| QueueDisabled | |   |
| QueueEmpty | |   |
| QueueFull | |   |





## Functions Documentation

### function ToString

```cpp
constexpr std::string_view ToString(
    QueueReturn val
)
```






-------------------------------

Updated on 2022-11-29 at 18:11:26 +0000
